imagemagick: A collection of tools and libraries for many image file formats
============================================================================

Description
-----------

A collection of tools and libraries for many image file formats

License
-------

Copyright [yyyy] [name of copyright owner]

Licensed under the ImageMagick License (the "License"); you may not use
this file except in compliance with the License.  You may obtain a copy
of the License at

    https://imagemagick.org/script/license.php

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
License for the specific language governing permissions and limitations
under the License.

Upstream Contact
----------------

http://www.imagemagick.org/
